<h2>Short Answer</h2>

```html
<p data-component="shortanswer" data-optional id="example1">What is the best thing about the color blue?</p>
```

The <code>p</code> tag represents the entire Short Answer component to be rendered.
(more info about the use)


Option spec:

<ul>
    <li><code>data-component="shortanswer"</code> Identifies this as a Short Answer component</li>
    <li><code>id</code> Must be unique in the document</li>
    <li><code>data-optional</code> Makes this component optional for the student to answer--it isn't required.</li>
</ul>
